@@ -121,6 +121,7 @@ import warnings
 import numpy as np
 from numpy import linalg as LA
 from numpy import fft as FFT
+import math
 
 from scipy.special import gamma as gammaF
 from scipy.misc import factorial
@@ -133,10 +134,7 @@ try:
     ORTHPOL_SUPPORT = True
 except ImportError:
     ORTHPOL_SUPPORT = False
-    warnings.simplefilter("default")
     warnings.warn("SpectralToolbox.Spectral1D: The orthpol pacakge is not installed on this machine. Functionalities associated with this package are disabled.", ImportWarning)
-else:
-    warnings.resetwarnings()
 
 JACOBI = 'Jacobi'
 HERMITEP = 'HermiteP'
@@ -1314,6 +1312,8 @@ class Poly1D(object):
                 r = np.array(r)
                 if (N >= k):
                     dP = gammaF(alpha+beta+N+1.+k)/(2.**k * gammaF(alpha+beta+N+1.)) * np.sqrt(self.__GammaJacobiP(N-k,alpha+k,beta+k)/self.__GammaJacobiP(N,alpha,beta)) * self.__JacobiP(r,N-k,alpha+k,beta+k)
+                else:
+                    dP = np.zeros(r.shape)
                 return dP
     
     def __GradChebyshevP(self,r, N, k, method=0):
@@ -1419,10 +1419,10 @@ class Poly1D(object):
         
         if (self.poly == JACOBI):
             if not norm:
-                p *= np.sqrt(self.Gamma(N))
+                p *= math.sqrt(self.Gamma(N))
         else:
             if norm:
-                p /= np.sqrt(self.Gamma(N))
+                p /= math.sqrt(self.Gamma(N))
         
         return p
     
@@ -1495,7 +1495,7 @@ class Poly1D(object):
         if (self.poly != HERMITEP):
             print >> self.sdout, "The method __GammaHermiteP cannot be called with the actual type of polynomials. Actual type: '%s'" % self.poly
         else:
-            return np.sqrt(np.pi) * 2.**N * factorial(N,exact=True)
+            return math.sqrt(np.pi) * 2.**N * factorial(N,exact=True)
         
     def __GammaHermiteF(self,N):
         """
