@@ -26,16 +26,7 @@
 # Author: Daniele Bigoni
 #
 
-"""
-
-Created on Wed Jul 11 10:40:30 2012
-
-@author: Daniele Bigoni (dabi@imm.dtu.dk)
-
-DABISpectralToolbox is the collection of tools for spectral methods and numerical integration.
-
-@copyright: 2012-2014 The Technical University of Denmark
-"""
+from _version import __version__
 
 __all__ = ["DABISparseGrids", "DABISpectral1D", "DABISpectralND", "DABIStroud", "DABIHeterogeneousSparseGrids", "DABIMisc"]
 
